﻿using Stimulsoft.Base.Localization;
using Stimulsoft.Helper.RT.Localization;
using Stimulsoft.Report;
using Stimulsoft.Report.Export;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage;
using Windows.System;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using System.Threading;
using Stimulsoft.Report.Chart;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace TesteStimulsoftReports
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
            this.Loaded += MainPage_Loaded;
        }

        async void MainPage_Loaded(object sender, RoutedEventArgs e)
        {                        
            LoadReport();
        }


        private async void LoadReport()
        {
            StiReport report = new StiReport();
           
            StorageFile storageFile = await Windows.ApplicationModel.Package.Current.InstalledLocation.GetFileAsync("Report1.mrt");
            if (storageFile != null)
            {
                await report.LoadAsync(storageFile);
                report.RegBusinessObject("People", "People", GetData());
                report.BeginRender += report_BeginRender;
                await report.RenderAsync();
                reportViewer.Report = report;
            }
        }

        private void report_BeginRender(object sender, EventArgs e)
        {
            StiReport rep = (StiReport)sender;
            StiChart chart = rep.GetComponents()["Chart1"] as StiChart;

            (((Stimulsoft.Report.Chart.StiAxis)(((Stimulsoft.Report.Chart.StiAxisArea)((chart as StiChart).Area)).XAxis)).Title).Text = "Dates";
            (((Stimulsoft.Report.Chart.StiAxis)(((Stimulsoft.Report.Chart.StiAxisArea)((chart as StiChart).Area)).YAxis)).Title).Text = "Temperature";
            (((Stimulsoft.Report.Chart.StiAxis)(((Stimulsoft.Report.Chart.StiAxisArea)((chart as StiChart).Area)).YRightAxis)).Title).Text = "Humidity";
        }


        private object GetData()
        {
            Person p = new Person();

            List<ChartData> ls = new List<ChartData>()
            {
                new ChartData(DateTime.Now,-3.0, 50.1),
                new ChartData(DateTime.Now.AddMinutes(10),27.3,56.7),
                new ChartData(DateTime.Now.AddMinutes(20),25.7,68.4),
                new ChartData(DateTime.Now.AddMinutes(30),22.5,41.8)
            };
            p.ChartDataList = ls;
            return p;
        }


        #region x
        private async void GetReport()
        { 
            StiReport report = new StiReport();
            var picker = new Windows.Storage.Pickers.FileOpenPicker();
            picker.FileTypeFilter.Add(".mrt");
            picker.SuggestedStartLocation = Windows.Storage.Pickers.PickerLocationId.ComputerFolder;
            StorageFile storageFile = storageFile = await picker.PickSingleFileAsync();

            if (storageFile != null)
            {
                await report.LoadAsync(storageFile);
                report.RegBusinessObject("People", "People", GetData());
                
                await report.RenderAsync();
                reportViewer.Report = report;
            }
        }

        private async void SendToPDF()
        {
                            
            //export to PDF
            StiPdfExportService exportPDFService = new StiPdfExportService();
            var pickerPDF = new Windows.Storage.Pickers.FileSavePicker();
            pickerPDF.FileTypeChoices.Add("Files report (*.pdf)", new List<string>() { ".pdf" });
            pickerPDF.SuggestedStartLocation = Windows.Storage.Pickers.PickerLocationId.ComputerFolder;
            pickerPDF.SuggestedFileName = "Report1PDF";
            var storageFilePDF = await pickerPDF.PickSaveFileAsync();
            if (storageFilePDF != null)
            {

                await exportPDFService.ExportPdfAsync(reportViewer.Report, storageFilePDF, new StiPdfExportSettings());
                await Launcher.LaunchFileAsync(storageFilePDF);
            }
                       
        }

        private async void RegisterTemplate()
        {
                      
            //used to get data structure so we can use it in report
            var picker = new Windows.Storage.Pickers.FileSavePicker();
            picker.FileTypeChoices.Add("Files report (*.mrt)", new List<string>() { ".mrt" });
            picker.SuggestedFileName = "Report1";
            picker.SuggestedStartLocation = Windows.Storage.Pickers.PickerLocationId.ComputerFolder;
            var storageFile = await picker.PickSaveFileAsync();
            if (storageFile != null)
            {
                StiReport report = new StiReport();
                report.RegBusinessObject("People", "People", GetData());
                report.Dictionary.SynchronizeBusinessObjects(3);
                await report.SaveAsync(storageFile);
            }
        }


       

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            RegisterTemplate();
        }

        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            GetReport();
        }

        private void Button_Click_2(object sender, RoutedEventArgs e)
        {
            SendToPDF();
        }
        #endregion

    }
}
